==> mediawiki_1.15.5.orig.tar.gz: mediawiki-1.15.5/languages/messages/MessagesAy.php <==
<?php
/** Aymara (Aymar aru)
 *
 * See MessagesQqq.php for message documentation incl. usage of parameters
 * To improve a translation please visit http://translatewiki.net
 *
 * @ingroup Language
 * @file
 *
 * @author Diego Grez
 * @author Erebedhel
 * @author Kanon6917
 */

$fallback = 'es';

$messages = array(
# User preference toggles
'tog-underline'               => 'Sipita siqiraña',
'tog-highlightbroken'         => 'P\'akita sipita utt\'ayaña <a href="" class="new">ukhama</a> (maykipa: ukhama<a href="" class="internal">?</a>).',
'tog-justify'                 => "Tanta amuyanak purapt'ayaña",
'tog-hideminor'               => 'Jichha jaqukipawina sullka askiptawix imantaña',
'tog-hidepatrolled'           => "Jichhnaki jaqukipawina askiptawix unch'ukita imantaña",
'tog-newpageshidepatrolled'   => "Machaqa uñstawix waruchatat uñstawix unch'ukita imantaña",
'tog-extendwatchlist'         => "Sarayawi jaqukipaw uñachayasuñatakiw unch'ukit waruch aqatatayaña",
'tog-usenewrc'                => 'Jichhnaki jaqukipawi waliptäta (JavaScript munawiwa)',
'tog-numberheadings'          => 'Titulun chinu achuraña',
'tog-showtoolbar'             => 'Turkawit irnaqañ täta tisi uñachayaña (JavaScript munawiwa)',
'tog-editondblclick'          => 'Uñstawi turkayaña päsuxuqiña (JavaScript munawiwa)',
'tog-editsection'             => '[Turkaña] sipitampi tuqitaki turkawi luräña',
'tog-editsectiononrightclick' => '(JavaScript munawiwa) titulxat tuqina kupi suxuqiñampi tuqitaki turkawi luräña',
'tog-showtoc'                 => 'Waruchataw uñachayaña (kimsa tituljampi uñstawitaki)',
'tog-rememberpassword'        => "Akax jasanchirin imt'awija amtaña",
'tog-editwidth'               => 'Akiptawit llataxa taqi anchuniwa',
'tog-watchcreations'          => "Unch'ukit waruchatajana nayaxa uñstawix uñstayawajata yapxataña",
'tog-watchdefault'            => "Unch'ukit waruchatajana nayaxa uñstawix turkajata yapxataña",
'tog-watchmoves'              => "Unch'ukit waruchatajana nayaxa uñstawix sutiyarajata yapxataña",
'tog-watchdeletion'           => "Unch'ukit waruchatajana nayaxa uñstawix phiskhurajata yapxataña",
'tog-minordefault'            => 'Sullka askiptawpacha chimpuriña',
'tog-previewontop'            => 'Askiptawit llataxa nayraxa uñtawikar uñachayaña',
'tog-previewonfirst'          => 'Mayïri askiptawina uñtawikar uñachayaña',
'tog-nocache'                 => "Uñstawita kachiñar jark'aña",
'tog-enotifwatchlistpages'    => "Nayaru chaski jalayiriña ukja unch'ukit waruchatana mäuñstawi turkañäna",
'tog-enotifusertalkpages'     => 'Nayaru chaski jalayiriña ukja tuqisiwit uñstawija turkañäna',
'tog-enotifminoredits'        => 'Nayaru chaski jalayiriña uñstawina sullka askiptawimpiraki',
'tog-enotifrevealaddr'        => 'Yatiyawita chaski jalayirinakana chaski jalayirit untjäwija uñachayaña',
'tog-shownumberswatching'     => "Qawqha apnaqirinaka uñch'ukiskar uñacht'ayaña",
'tog-fancysig'                => "Mayaxta rixt'a (sipitarachayatawisa)",
'tog-externaleditor'          => "Anqa askiptiri mirq'iriña (yatxiritakiwa, jasanchirina ajalla jamuqawi wakiskiriwa)",
'tog-externaldiff'            => "Anqa diff-iri mirq'iriña (yatxiritakiwa, jasanchirina ajalla jamuqawi wakiskiriwa)",
'tog-showjumplinks'           => 'Usutataki sipitata "khänaru thuqtaña" uñachayaña',
'tog-uselivepreview'          => "Uñtawikach'ukix mirq'iña (JavaScript munawiwa) (yant'awiwaki)",
'tog-forceeditsummary'        => "Nayaru yatiyaña ukja ch'usa askiptawit juk'aptayawi apantaskaña",
'tog-watchlisthideown'        => "Unch'ukit waruchatana askiptawijax imantaña",
'tog-watchlisthidebots'       => "Unch'ukit waruchatana bot-ta askiptawipax imantaña",
'tog-watchlisthideminor'      => "Unch'ukit waruchatana sullka askiptawix imantaña",
'tog-watchlisthideliu'        => "Unch'ukit waruchatana qillqt'ayasita apnaqirina askiptawipax imantaña",
'tog-watchlisthideanons'      => "Unch'ukit waruchatana sutiwisa apnaqirina askiptawipax imantaña",
'tog-watchlisthidepatrolled'  => "Unch'ukit waruchatana unch'ukit askiptawix imantaña",
'tog-nolangconversion'        => "Yaqha aruptaxa jark'aña",
'tog-ccmeonemails'            => 'Chaski jalayirija nayax yaqhar apayayäta qillqaqawix nayaru apayaña',
'tog-diffonly'                => 'Manqha diff-nakax uñstawit yati utjawi janiw uñachayaña',
'tog-showhiddencats'          => 'Imantata patawix uñachayaña',

'underline-always' => 'Wiñaya',
'underline-never'  => 'Janipini',

# Dates
'sunday'        => 'tuminku',
'monday'        => 'lunisa',
'tuesday'       => 'martisa',
'wednesday'     => 'mirkulisa',
'thursday'      => 'juywisa',
'friday'        => 'wirnisa',
'saturday'      => 'sawaru',
'sun'           => 'tum',
'mon'           => 'lun',
'tue'           => 'mar',
'wed'           => 'mir',
'thu'           => 'juy',
'fri'           => 'wir',
'sat'           => 'saw',
'january'       => 'chichu phaxsi',
'february'      => 'anata phaxsi',
'march'         => 'achuqa phaxsi',
'april'         => 'yapu apthapi phaxsi',
'may_long'      => 'llamayu phaxsi',
'june'          => 'juyphi phaxsi',
'july'          => 'huillka kuti phaxsi',
'august'        => 'thaya phaxsi',
'september'     => "llamp'u phaxsi",
'october'       => 'taypi sata phaxsi',
'november'      => 'awti phaxsi',
'december'      => 'jallu qallta phaxsi',
'january-gen'   => 'chichu phaxsi',
'february-gen'  => 'anata phaxsi',
'march-gen'     => 'achuqa phaxsi',
'april-gen'     => 'yapu apthapi phaxsi',
'may-gen'       => 'llamayu phaxsi',
'june-gen'      => 'juyphi phaxsi',
'july-gen'      => 'huillka kuti phaxsi',
'august-gen'    => 'thaya phaxsi',
'september-gen' => "llamp'u phaxsi",
'october-gen'   => 'taypi sata phaxsi',
'november-gen'  => 'awti phaxsi',
'december-gen'  => 'jallu qallta phaxsi',
'jan'           => 'chi',
'feb'           => 'ana',
'mar'           => 'ach',
'apr'           => 'yap',
'may'           => 'llam',
'jun'           => 'juy',
'jul'           => 'hui',
'aug'           => 'tha',
'sep'           => 'llmp',
'oct'           => 'tay',
'nov'           => 'awt',
'dec'           => 'jall',

'article'       => 'Amtachinu',
'cancel'        => 'Jan saña',
'qbfind'        => 'Thaqaña',
'qbbrowse'      => 'Wampuña',
'qbedit'        => 'Turkaña',
'qbpageoptions' => 'Uñstawitaki ajllita',
'qbpageinfo'    => "Uñstawxat uñt'ayawi",
'qbmyoptions'   => 'Ajllitanakaja',
'moredotdotdot' => 'Yapa...',
'mypage'        => 'Uñstawija',
'navigation'    => 'Wampuña',
'and'           => '&#32;-mpi',

'errorpagetitle'    => 'Pantja',
'help'              => 'Yanapaña',
'search'            => 'Thaqaña',
'searchbutton'      => 'Thaqaña',
'go'                => 'Saraña',
'searcharticle'     => 'Saraña',
'history'           => 'Nayra qillqata',
'history_short'     => 'Nayra qillqata',
'info_short'        => "Uñt'ayawi",
'edit'              => 'Turkaña',
'create'            => 'Uñstayaña',
'editthispage'      => 'Aka uñstawi turkaña',
'create-this-page'  => 'Aka uñstawi uñstayaña',
'delete'            => 'Pichaña',
'deletethispage'    => 'Aka uñstawi phiskhuraña',
'undelete_short'    => "{{PLURAL:$1|mayaskiptawi|$1 askiptanakawi}} kutt'ayxaña",
'protect'           => "Jark'aña",
'protect_change'    => 'turkaña',
'protectthispage'   => "Aka uñstawi jark'aña",
'unprotect'         => "Jark'ch'ukiña",
'unprotectthispage' => "Aka uñstawi jark'ch'ukiña",
'newpage'           => 'Machaqa uñstawi',
'talkpage'          => 'Aka uñstawxat tuqisiña',
'talkpagelinktext'  => 'Kutkatasiña',
'specialpage'       => 'Ajalla Uñstawi',
'talk'              => 'Tuqisiwi',
'otherlanguages'    => 'Yaqha arunaka',
'protectedpage'     => "Uñstawi jark'ata",
'jumptonavigation'  => 'wampuña',
'jumptosearch'      => 'thaqaña',

# All link text and link target definitions of links into project namespace that get used by other message strings, with the exception of user group pages (see grouppage) and the disambiguation template definition (see disambiguations).
'currentevents'        => 'Jichha pacha',
'currentevents-url'    => 'Project:Jichha pacha',
'mainpage'             => 'Nayriri Uñstawi',
'mainpage-description' => 'Nayriri Uñstawi',
'portal'               => 'Jayma punku',
'portal-url'           => 'Project:Jayma punku',

'editsection'    => 'turkaña',
'editold'        => 'turkaña',
'editlink'       => 'trukaña',
'showtoc'        => 'uñachayaña',
'site-rss-feed'  => '$1 RSS jalsuri',
'site-atom-feed' => '$1 Atom jalsuri',
'page-rss-feed'  => '"$1" RSS jalsuri',
'page-atom-feed' => '"$1" Atom jalsuri',

# Short words for each namespace, by default used in the namespace tab in monobook
'nstab-main'     => 'Amtachinu',
'nstab-user'     => 'Apnaqiri',
'nstab-image'    => "Q'ipi",
'nstab-help'     => 'Yanapaña',
'nstab-category' => 'Patawi',

# General errors
'error' => 'Pantja',

# Login and logout pages
'loginpagetitle'     => "Qillqt'ayasiña",
'login'              => "Qillqt'ayasiña",
'userlogin'          => "Qillqt'ayasiña",
'logout'             => 'Mistuña',
'userlogout'         => 'Mistuña',
'yourlanguage'       => 'Aru:',
'email'              => 'Chaski jalayiri',
'loginlanguagelabel' => 'Aru: $1',

# Edit pages
'summary'   => 'Juk’aptayäwi:',
'subject'   => 'Yatsuwi/titulu:',
'minoredit' => 'Akax janiw taqpachäkiti',
'yourdiff'  => 'Jalaqtatanaka',

# Preferences page
'preferences'    => 'Amtajarjama',
'prefs-rc'       => 'Jichha kutikiptatanaka',
'timezoneoffset' => 'Jalaqtata',

# Recent changes
'recentchanges' => 'Jichha kutikiptatanaka',
'show'          => 'uñachayaña',

# Upload
'fileuploadsummary' => 'Uñt’ayawi:',

'license' => 'Iyawsawi:',

# Special:ListFiles
'listfiles_date'        => 'Uru jakhu',
'listfiles_user'        => 'Apnaqiri',
'listfiles_description' => 'Uñt’ayawi',

# File description page
'filehist-user' => 'Apnaqiri',

# Miscellaneous special pages
'move' => 'Qillqaraña',

# Book sources
'booksources-go' => 'Saraña',

# Special:Log
'specialloguserlabel'  => 'Apnaqiri:',
'speciallogtitlelabel' => 'Titulu:',

# Special:ListUsers
'listusers-submit' => 'Uñachayaña',

# Watchlist
'watch' => 'Uñjaña',

# Restrictions (nouns)
'restriction-move' => 'Qillqaraña',

# Undelete
'undelete-search-submit' => 'Thaqaña',

'sp-contributions-submit' => 'Thaqaña',

# Block/unblock
'ipblocklist-submit' => 'Thaqaña',
'proxyblocksuccess'  => 'Kamachawi',

# Tooltip help for the actions
'tooltip-p-logo' => 'Nayriri Uñstawi',

# Attribution
'others' => 'yaqha',

# action=purge
'confirm_purge_button' => 'Iyawa saña',

# Multipage image navigation
'imgmultigo' => '¡Saraña!',

# Table pager
'table_pager_limit_submit' => 'Saraña',

);

==> mediawiki-1.17.4.tar.gz: mediawiki-1.17.4/languages/messages/MessagesAy.php <==
<?php
/** Aymara (Aymar aru)
 *
 * See MessagesQqq.php for message documentation incl. usage of parameters
 * To improve a translation please visit http://translatewiki.net
 *
 * @ingroup Language
 * @file
 *
 * @author Alhen
 * @author Diego Grez
 * @author Erebedhel
 * @author Kanon6917
 */

$fallback = 'es';

$messages = array(
# User preference toggles
'tog-underline'               => 'Sipita siqiraña',
'tog-highlightbroken'         => 'P\'akita sipita utt\'ayaña <a href="" class="new">ukhama</a> (maykipa: ukhama<a href="" class="internal">?</a>).',
'tog-justify'                 => "Tanta amuyanak purapt'ayaña",
'tog-hideminor'               => 'Jichha jaqukipawina sullka askiptawix imantaña',
'tog-hidepatrolled'           => "Jichhnaki jaqukipawina askiptawix unch'ukita imantaña",
'tog-newpageshidepatrolled'   => "Machaqa uñstawix waruchatat uñstawix unch'ukita imantaña",
'tog-extendwatchlist'         => "Sarayawi jaqukipaw uñachayasuñatakiw unch'ukit waruch aqatatayaña",
'tog-usenewrc'                => 'Jichhnaki jaqukipawi waliptäta (JavaScript munawiwa)',
'tog-numberheadings'          => 'Titulun chinu achuraña',
'tog-showtoolbar'             => 'Turkawit irnaqañ täta tisi uñachayaña (JavaScript munawiwa)',
'tog-editondblclick'          => 'Uñstawi turkayaña päsuxuqiña (JavaScript munawiwa)',
'tog-editsection'             => '[Turkaña] sipitampi tuqitaki turkawi luräña',
'tog-editsectiononrightclick' => '(JavaScript munawiwa) titulxat tuqina kupi suxuqiñampi tuqitaki turkawi luräña',
'tog-showtoc'                 => 'Waruchataw uñachayaña (kimsa tituljampi uñstawitaki)',
'tog-rememberpassword'        => "Akax jasanchirin imt'awija amtaña (for a maximum of $1 {{PLURAL:$1|day|days}})",
'tog-watchcreations'          => "Unch'ukit waruchatajana nayaxa uñstawix uñstayawajata yapxataña",
'tog-watchdefault'            => "Unch'ukit waruchatajana nayaxa uñstawix turkajata yapxataña",
'tog-watchmoves'              => "Unch'ukit waruchatajana nayaxa uñstawix sutiyarajata yapxataña",
'tog-watchdeletion'           => "Unch'ukit waruchatajana nayaxa uñstawix phiskhurajata yapxataña",
'tog-minordefault'            => 'Sullka askiptawpacha chimpuriña',
'tog-previewontop'            => 'Askiptawit llataxa nayraxa uñtawikar uñachayaña',
'tog-previewonfirst'          => 'Mayïri askiptawina uñtawikar uñachayaña',
'tog-nocache'                 => "Uñstawita kachiñar jark'aña",
'tog-enotifwatchlistpages'    => "Nayaru chaski jalayiriña ukja unch'ukit waruchatana mäuñstawi turkañäna",
'tog-enotifusertalkpages'     => 'Nayaru chaski jalayiriña ukja tuqisiwit uñstawija turkañäna',
'tog-enotifminoredits'        => 'Nayaru chaski jalayiriña uñstawina sullka askiptawimpiraki',
'tog-enotifrevealaddr'        => 'Yatiyawita chaski jalayirinakana chaski jalayirit untjäwija uñachayaña',
'tog-shownumberswatching'     => "Qawqha apnaqirinaka uñch'ukiskar uñacht'ayaña",
'tog-fancysig'                => "Mayaxta rixt'a (sipitarachayatawisa)",
'tog-externaleditor'          => "Anqa askiptiri mirq'iriña (yatxiritakiwa, jasanchirina ajalla jamuqawi wakiskiriwa)",
'tog-externaldiff'            => "Anqa diff-iri mirq'iriña (yatxiritakiwa, jasanchirina ajalla jamuqawi wakiskiriwa)",
'tog-showjumplinks'           => 'Usutataki sipitata "khänaru thuqtaña" uñachayaña',
'tog-uselivepreview'          => "Uñtawikach'ukix mirq'iña (JavaScript munawiwa) (yant'awiwaki)",
'tog-forceeditsummary'        => "Nayaru yatiyaña ukja ch'usa askiptawit juk'aptayawi apantaskaña",
'tog-watchlisthideown'        => "Unch'ukit waruchatana askiptawijax imantaña",
'tog-watchlisthidebots'       => "Unch'ukit waruchatana bot-ta askiptawipax imantaña",
'tog-watchlisthideminor'      => "Unch'ukit waruchatana sullka askiptawix imantaña",
'tog-watchlisthideliu'        => "Unch'ukit waruchatana qillqt'ayasita apnaqirina askiptawipax imantaña",
'tog-watchlisthideanons'      => "Unch'ukit waruchatana sutiwisa apnaqirina askiptawipax imantaña",
'tog-watchlisthidepatrolled'  => "Unch'ukit waruchatana unch'ukit askiptawix imantaña",
'tog-nolangconversion'        => "Yaqha aruptaxa jark'aña",
'tog-ccmeonemails'            => 'Chaski jalayirija nayax yaqhar apayayäta qillqaqawix nayaru apayaña',
'tog-diffonly'                => 'Manqha diff-nakax uñstawit yati utjawi janiw uñachayaña',
'tog-showhiddencats'          => 'Imantata patawix uñachayaña',

'underline-always' => 'Wiñaya',
'underline-never'  => 'Janipini',

# Dates
'sunday'        => 'tuminku',
'monday'        => 'lunisa',
'tuesday'       => 'martisa',
'wednesday'     => 'mirkulisa',
'thursday'      => 'juywisa',
'friday'        => 'wirnisa',
'saturday'      => 'sawaru',
'sun'           => 'tum',
'mon'           => 'lun',
'tue'           => 'mar',
'wed'           => 'mir',
'thu'           => 'juy',
'fri'           => 'wir',
'sat'           => 'saw',
'january'       => 'chichu phaxsi',
'february'      => 'anata phaxsi',
'march'         => 'achuqa phaxsi',
'april'         => 'yapu apthapi phaxsi',
'may_long'      => 'llamayu phaxsi',
'june'          => 'juyphi phaxsi',
'july'          => 'huillka kuti phaxsi',
'august'        => 'thaya phaxsi',
'september'     => "llamp'u phaxsi",
'october'       => 'taypi sata phaxsi',
'november'      => 'awti phaxsi',
'december'      => 'jallu qallta phaxsi',
'january-gen'   => 'chichu phaxsi',
'february-gen'  => 'anata phaxsi',
'march-gen'     => 'achuqa phaxsi',
'april-gen'     => 'yapu apthapi phaxsi',
'may-gen'       => 'llamayu phaxsi',
'june-gen'      => 'juyphi phaxsi',
'july-gen'      => 'huillka kuti phaxsi',
'august-gen'    => 'thaya phaxsi',
'september-gen' => "llamp'u phaxsi",
'october-gen'   => 'taypi sata phaxsi',
'november-gen'  => 'awti phaxsi',
'december-gen'  => 'jallu qallta phaxsi',
'jan'           => 'chi',
'feb'           => 'ana',
'mar'           => 'ach',
'apr'           => 'yap',
'may'           => 'llam',
'jun'           => 'juy',
'jul'           => 'hui',
'aug'           => 'tha',
'sep'           => 'llmp',
'oct'           => 'tay',
'nov'           => 'awt',
'dec'           => 'jall',

'article'       => 'Amtachinu',
'cancel'        => 'Jan saña',
'moredotdotdot' => 'Yapa...',
'mypage'        => 'Uñstawija',
'navigation'    => 'Wampuña',
'and'           => '&#32;-mpi',

# Cologne Blue skin
'qbfind'        => 'Thaqaña',
'qbbrowse'      => 'Wampuña',
'qbedit'        => 'Turkaña',
'qbpageoptions' => 'Uñstawitaki ajllita',
'qbpageinfo'    => "Uñstawxat uñt'ayawi",
'qbmyoptions'   => 'Ajllitanakaja',

'errorpagetitle'    => 'Pantja',
'help'              => 'Yanapaña',
'search'            => 'Thaqaña',
'searchbutton'      => 'Thaqaña',
'go'                => 'Saraña',
'searcharticle'     => 'Saraña',
'history'           => 'Nayra qillqata',
'history_short'     => 'Nayra qillqata',
'info_short'        => "Uñt'ayawi",
'edit'              => 'Turkaña',
'create'            => 'Uñstayaña',
'editthispage'      => 'Aka uñstawi turkaña',
'create-this-page'  => 'Aka uñstawi uñstayaña',
'delete'            => 'Pichaña',
'deletethispage'    => 'Aka uñstawi phiskhuraña',
'undelete_short'    => "{{PLURAL:$1|mayaskiptawi|$1 askiptanakawi}} kutt'ayxaña",
'protect'           => "Jark'aña",
'protect_change'    => 'turkaña',
'protectthispage'   => "Aka uñstawi jark'aña",
'unprotect'         => "Jark'ch'ukiña",
'unprotectthispage' => "Aka uñstawi jark'ch'ukiña",
'newpage'           => 'Machaqa uñstawi',
'talkpage'          => 'Aka uñstawxat tuqisiña',
'talkpagelinktext'  => 'Kutkatasiña',
'specialpage'       => 'Ajalla Uñstawi',
'talk'              => 'Tuqisiwi',
'otherlanguages'    => 'Yaqha arunaka',
'protectedpage'     => "Uñstawi jark'ata",
'jumptonavigation'  => 'wampuña',
'jumptosearch'      => 'thaqaña',

# All link text and link target definitions of links into project namespace that get used by other message strings, with the exception of user group pages (see grouppage) and the disambiguation template definition (see disambiguations).
'currentevents'        => 'Jichha pacha',
'currentevents-url'    => 'Project:Jichha pacha',
'mainpage'             => 'Nayriri Uñstawi',
'mainpage-description' => 'Nayriri Uñstawi',
'portal'               => 'Jayma punku',
'portal-url'           => 'Project:Jayma punku',

'editsection'    => 'turkaña',
'editold'        => 'turkaña',
'editlink'       => 'trukaña',
'toc'            => 'Utjirinaka',
'showtoc'        => 'uñachayaña',
'site-rss-feed'  => '$1 RSS jalsuri',
'site-atom-feed' => '$1 Atom jalsuri',
'page-rss-feed'  => '"$1" RSS jalsuri',
'page-atom-feed' => '"$1" Atom jalsuri',

# Short words for each namespace, by default used in the namespace tab in monobook
'nstab-main'     => 'Amtachinu',
'nstab-user'     => 'Apnaqiri',
'nstab-image'    => "Q'ipi",
'nstab-help'     => 'Yanapaña',
'nstab-category' => 'Patawi',

# General errors
'error' => 'Pantja',

# Login and logout pages
'login'              => "Qillqt'ayasiña",
'userlogin'          => "Qillqt'ayasiña",
'logout'             => 'Mistuña',
'userlogout'         => 'Mistuña',
'loginlanguagelabel' => 'Aru: $1',

# Edit pages
'summary'   => 'Juk’aptayäwi:',
'subject'   => 'Yatsuwi/titulu:',
'minoredit' => 'Akax janiw taqpachäkiti',
'yourdiff'  => 'Jalaqtatanaka',

# Preferences page
'preferences'    => 'Amtajarjama',
'prefs-rc'       => 'Jichha kutikiptatanaka',
'timezoneoffset' => 'Jalaqtata',
'yourlanguage'   => 'Aru:',
'email'          => 'Chaski jalayiri',

# Recent changes
'recentchanges' => 'Jichha kutikiptatanaka',
'show'          => 'uñachayaña',

# Upload
'fileuploadsummary' => 'Uñt’ayawi:',

'license'        => 'Iyawsawi:',
'license-header' => 'Iyawsawi:',

# Special:ListFiles
'listfiles_date'        => 'Uru jakhu',
'listfiles_user'        => 'Apnaqiri',
'listfiles_description' => 'Uñt’ayawi',

# File description page
'file-anchor-link' => "Q'ipi",
'filehist-user'    => 'Apnaqiri',

# Miscellaneous special pages
'move' => 'Qillqaraña',

# Book sources
'booksources-go' => 'Saraña',

# Special:Log
'specialloguserlabel'  => 'Apnaqiri:',
'speciallogtitlelabel' => 'Titulu:',

# Special:ListUsers
'listusers-submit' => 'Uñachayaña',

# Watchlist
'watch' => 'Uñjaña',

# Restrictions (nouns)
'restriction-move' => 'Qillqaraña',

# Undelete
'undelete-search-submit' => 'Thaqaña',

'sp-contributions-talk'   => 'Kutkatasiña',
'sp-contributions-submit' => 'Thaqaña',

# Block/unblock
'ipblocklist-submit' => 'Thaqaña',
'proxyblocksuccess'  => 'Kamachawi',

# Tooltip help for the actions
'tooltip-p-logo' => 'Nayriri Uñstawi',

# Attribution
'others' => 'yaqha',

# action=purge
'confirm_purge_button' => 'Iyawa saña',

# Multipage image navigation
'imgmultigo' => '¡Saraña!',

# Table pager
'table_pager_limit_submit' => 'Saraña',

);
